from datetime import datetime
from zoneinfo import ZoneInfo

from edc_consent.consent import Consent
from edc_consent.site_consents import site_consents
from edc_constants.constants import FEMALE, MALE

v1 = Consent(
    "next_appointment_app.subjectconsent",
    version="1",
    start=datetime(2018, 1, 1, 0, 0, tzinfo=ZoneInfo("UTC")),
    end=datetime(2023, 1, 1, 0, 0, tzinfo=ZoneInfo("UTC")),
    age_min=18,
    age_is_adult=18,
    age_max=110,
    gender=[MALE, FEMALE],
)

site_consents.register(v1)



from django.utils.translation import gettext_lazy as _
from edc_constants.constants import (
    ESTIMATED,
    HOSPITAL_NOTES,
    OTHER,
    OUTPATIENT_CARDS,
    PATIENT,
    PATIENT_REPRESENTATIVE,
)

list_data = {
    "edc_next_appointment.infosources": [
        (PATIENT, _("Patient")),
        (
            PATIENT_REPRESENTATIVE,
            _("Patient representative (e.g., next of kin, relative, guardian)"),
        ),
        (HOSPITAL_NOTES, _("Hospital notes")),
        (OUTPATIENT_CARDS, _("Outpatient cards")),
        (ESTIMATED, _("Estimated by research staff")),
        (OTHER, _("Other")),
    ],
    "edc_visit_tracking.subjectvisitmissedreasons": [
        ("forgot", _("Forgot / Can’t remember being told about appointment")),
        ("family_emergency", _("Family emergency (e.g. funeral) and was away")),
        ("travelling", _("Away travelling/visiting")),
        ("working_schooling", _("Away working/schooling")),
        ("too_sick", _("Too sick or weak to come to the centre")),
        ("lack_of_transport", _("Transportation difficulty")),
        (OTHER, _("Other reason (specify below)")),
    ],
}



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin

from edc_next_appointment.form_validators import NextAppointmentFormValidator
from edc_next_appointment.modelform_mixins import NextAppointmentModelFormMixin

from .models import NextAppointment


class NextAppointmentForm(NextAppointmentModelFormMixin, CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = NextAppointmentFormValidator

    def validate_against_consent(self) -> None:
        pass

    class Meta:
        model = NextAppointment
        fields = "__all__"
